==> haskell-here-1.2.14-129.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-here.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 here
version:              1.2.14
visibility:           public
id:                   here-1.2.14-4siWxaqoM6a11ah3qknSEL
key:                  here-1.2.14-4siWxaqoM6a11ah3qknSEL
license:              BSD-3-Clause
copyright:            ©2013 Taylor M. Hedberg, ©2014 Google Inc.
maintainer:           t@tmh.cc
author:               Taylor M. Hedberg
homepage:             https://github.com/tmhedberg/here
synopsis:             Here docs & interpolated strings via quasiquotation
description:          Here docs & interpolated strings via quasiquotation
category:             Data
abi:                  86722bb0aac09a8e9a865156c3ec190b
exposed:              True
exposed-modules:
    Data.String.Here Data.String.Here.Interpolated
    Data.String.Here.Uninterpolated

hidden-modules:       Data.String.Here.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/here-1.2.14
library-dirs:         /usr/lib/ghc-9.6.6/site-local/here-1.2.14
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/here-1.2.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-here
hs-libraries:         HShere-1.2.14-4siWxaqoM6a11ah3qknSEL
depends:
    base-4.18.2.1 haskell-src-meta-0.8.15-GqSWx9monJhDwN3u4roT6d
    mtl-2.3.1 parsec-3.1.16.1 template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-here/html/here.haddock
haddock-html:         /usr/share/doc/haskell-here/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-here-1.2.14-130-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-here.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 here
version:              1.2.14
visibility:           public
id:                   here-1.2.14-KwektgaqUpn6Qu7M9QBR0l
key:                  here-1.2.14-KwektgaqUpn6Qu7M9QBR0l
license:              BSD-3-Clause
copyright:            ©2013 Taylor M. Hedberg, ©2014 Google Inc.
maintainer:           t@tmh.cc
author:               Taylor M. Hedberg
homepage:             https://github.com/tmhedberg/here
synopsis:             Here docs & interpolated strings via quasiquotation
description:          Here docs & interpolated strings via quasiquotation
category:             Data
abi:                  907cb9201419f3c642f7ecdc2b7c2871
exposed:              True
exposed-modules:
    Data.String.Here Data.String.Here.Interpolated
    Data.String.Here.Uninterpolated

hidden-modules:       Data.String.Here.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/here-1.2.14
library-dirs:         /usr/lib/ghc-9.6.6/site-local/here-1.2.14
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/here-1.2.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-here
hs-libraries:         HShere-1.2.14-KwektgaqUpn6Qu7M9QBR0l
depends:
    base-4.18.2.1 haskell-src-meta-0.8.15-5WA14dofYHdB0COx7SkwL2
    mtl-2.3.1 parsec-3.1.16.1 template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-here/html/here.haddock
haddock-html:         /usr/share/doc/haskell-here/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
